@@ -1,4 +1,4 @@
-// $Id: blacklist.h,v 1.4 2003/08/21 14:33:55 ensc Exp $    --*- c++ -*--
+// $Id: blacklist.h,v 1.6 2003/10/07 17:21:20 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002,2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -22,7 +22,10 @@
 #include "vector.h"
 
 #include <netinet/in.h>
+#include <net/ethernet.h>
 #include <time.h>
+#include <stdbool.h>
+#include <compat.h>
 
 struct Arguments;
 
@@ -35,8 +38,17 @@ typedef struct {
     struct Arguments const *	args_;
 } BlackList;
 
+struct BlackListQuery {
+    struct ether_addr			result_buffer_;
+    struct in_addr const * const	ip;		/* in */
+    struct ether_addr const * const	mac;		/* in */
+    struct ether_addr const *		poison_mac;	/* out */
+};
+    
+    
+
 struct ether_addr const *
-BlackList_getMac(BlackList const *lst, struct in_addr const ip, struct ether_addr *res);
+BlackList_getMac(BlackList const *lst, struct BlackListQuery *query);
 
 void		BlackList_init(BlackList *lst, struct Arguments const *args);
 void		BlackList_free(BlackList *);
