@@ -1,4 +1,4 @@
-// $Id: ip-sentinel.h,v 1.3 2003/05/26 21:49:22 ensc Exp $    --*- c++ -*--
+// $Id: ip-sentinel.h,v 1.4 2003/08/22 14:39:48 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002,2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -24,7 +24,7 @@
 #include <stdbool.h>
 #include <signal.h>
 
-extern volatile sig_atomic_t	child_count;
+extern struct ether_addr	local_mac_address;
 
 inline static bool
 isDOS(unsigned int count)
