@@ -20,7 +20,7 @@ function execprog()
 function verify()
 {
     sed -e "${REPLACE_REGEX}" ${outfile_out} |
-	diff -b -c - ${basefile}.out || exit 1
+	$DIFF - ${basefile}.out || exit 1
 }
 
 
